% -----------------------------------------------------------
%      plot_SW59
%
%    Webb acdc VLA
%
%    loads data and makes a color plot of temp at SW45
%
% SW59                  80      31 aug 14:00    Webb â acdc array
%                                       38 16.138  072 51.721
%       SBE37   4284    15.33 -no date in file  SW59-SBE37-4284.cap
%       Mini-T  2301    16.6                    SW59_T2301.dat
%       Mini-T  2299    24.6                    SW59_T2297.dat
%       Mini-T  2023    32.6                    SW59_T2023.dat
%       Mini-T  2304    40.6                    SW59_T2304.dat
%       Mini-T  2300    48.6                    SW59_T2300.dat
%       Mini-T  2297    56.6                    SW59_T2297.dat
%       Mini-T  2298    64.6                    SW59_T2298.dat
%       Mini-T  2049    72.6                    SW59_T2049.dat
%
%
%
% ---------------------------------------------------------


load SW59;

mst = datenum(2006,8,31,12,0,0);
mend = datenum(2006,9,8,12,0,0);

mt = mst:1/60/24:mend;

Z = SW59.Zsens(2:9);

T1 = interp1(T2301.mday,T2301.t,mt);
T2 = interp1(T2299.mday,T2299.t,mt);
T3 = interp1(T2023.mday,T2023.t,mt);
T4 = interp1(T2304.mday,T2304.t,mt);
T5 = interp1(T2300.mday,T2300.t,mt);
T6 = interp1(T2297.mday,T2297.t,mt);
T7 = interp1(T2298.mday,T2298.t,mt);
T8 = interp1(T2049.mday,T2049.t,mt);
 
T = [T1; T2; T3; T4; T5; T6; T7; T8 ];

pcolor(mt,Z,T);shading('interp');
axis('ij');  datetick

title('SW59 Temperature','fontweight','b');
xlabel('Date','fontweight','b'); ylabel('Depth (m)','fontweight','b');

caxis([8 30]);
hcb = colorbar('v6');
set(hcb,'position',[0.83 0.15 0.029 0.4075]);
set(get(hcb,'title'),'string','Deg(c)');

box('on');set(gca,'linewidth',2);set(gca,'ticklength',[0 0])



